@@ -1,9 +1,9 @@
-from django.db import models
-from django.db import transaction
+from django.db import models, transaction
 from django.conf import settings
-from django.dispatch import receiver
-from django.db.models.signals import pre_save
 from django.contrib.auth.models import User
+from django.core import signing
+from django.db.models.signals import pre_save
+from django.dispatch import receiver
 
 from . import utils
 
@@ -60,6 +60,17 @@ class Subscription(models.Model):
     # Aditional parameters for deep link
     quiz = models.TextField(null=True, blank=True)
 
+    def get_token(self):
+        """
+        Returns Token signed via django.core.signing.Signer.
+        :return str:
+        """
+        signer = signing.Signer()
+        return signer.sign_object({
+                    'id': self.pk,
+                    'sub': self.subscription_id,
+                })
+
     class Meta:
         unique_together = [('user', 'plan')]
 
