@@ -57,7 +57,11 @@ def subscribe(request):
             if sub:
                 return JsonResponse({
                     "status": "ok",
-                    "deep_link": sub.deep_link
+                    "deep_link": '%s&email=%s&user_ip=%s' % (
+                        sub.deep_link,
+                        request.user.email,
+                        request.META['REMOTE_ADDR']
+                    )
                 })
         else:
             return JsonResponse(
